==> tuyaos_demo_ipc_1.0.7.tar.gz: tuyaos_demo_ipc/include/tuya_ipc_media_demo.h <==
/*********************************************************************************
  *Copyright(C),2015-2020, 
  *TUYA 
  *www.tuya.comm
  *FileName:    tuya_ipc_media_demo.h
**********************************************************************************/


#ifndef _TUYA_IPC_MEDIA_H
#define _TUYA_IPC_MEDIA_H

#include "tuya_ring_buffer.h"
#include "tuya_cloud_types.h"


#ifdef __cplusplus
extern "C" {
#endif

#define MAX_SNAPSHOT_BUFFER_SIZE            (100*1024)  //in BYTE

typedef struct
{
	IPC_MEDIA_INFO_T media_info;
  IPC_MEDIA_INFO_T media_info2;//another sensor
}TUYA_IPC_SDK_MEDIA_STREAM_S;

VOID TUYA_APP_Enable_Speaker_CB(BOOL_T enabled);

VOID TUYA_APP_Rev_Audio_CB(IN CONST MEDIA_FRAME_T *p_audio_frame,
                           TUYA_AUDIO_SAMPLE_E audio_sample,
                           TUYA_AUDIO_DATABITS_E audio_databits,
                           TUYA_AUDIO_CHANNEL_E audio_channel);

VOID *thread_live_video(VOID *arg);
VOID *thread_live_audio(VOID *arg);

void *thread_live_video2(void *arg);


VOID IPC_APP_Init_Media_Task();


/* get snapshot*/
int IPC_APP_get_snapshot(char *snap_addr, int *snap_size);

/* TUYA_APP_Init_Ring_Buffer */
OPERATE_RET TUYA_APP_Init_Ring_Buffer(CONST IPC_MEDIA_INFO_T *pMediaInfo, INT_T channel);

/* Send the raw data of audio and video  to the SDK */
OPERATE_RET TUYA_APP_Put_Frame(RING_BUFFER_USER_HANDLE_T handle,IN CONST MEDIA_FRAME_T *p_frame);

/* snapshot callback of TUYA SDK*/
OPERATE_RET TUYA_APP_get_snapshot_cb(IN INT_T device, IN INT_T channel, OUT CHAR_T *snap_addr, OUT INT_T *snap_size);

OPERATE_RET TUYA_APP_DeInit_Ring_Buffer(INT_T channel);

#ifdef __cplusplus
}
#endif

#endif  /* _TUYA_IPC_MEDIA_UTILS_H */

==> tuyaos_demo_ipc_1.0.14.tar.gz: tuyaos_demo_ipc/include/tuya_ipc_media_demo.h <==
/*********************************************************************************
  *Copyright(C),2015-2020, 
  *TUYA 
  *www.tuya.comm
  *FileName:    tuya_ipc_media_demo.h
**********************************************************************************/


#ifndef _TUYA_IPC_MEDIA_H
#define _TUYA_IPC_MEDIA_H

#include "tuya_ring_buffer.h"
#include "tuya_cloud_types.h"


#ifdef __cplusplus
extern "C" {
#endif

#define MAX_SNAPSHOT_BUFFER_SIZE            (100*1024)  //in BYTE

typedef struct
{
	IPC_MEDIA_INFO_T media_info;
  IPC_MEDIA_INFO_T media_info2;//another sensor
}TUYA_IPC_SDK_MEDIA_STREAM_S;

VOID TUYA_APP_Enable_Speaker_CB(BOOL_T enabled);

VOID TUYA_APP_Rev_Audio_CB(IN CONST MEDIA_FRAME_T *p_audio_frame,
                           TUYA_AUDIO_SAMPLE_E audio_sample,
                           TUYA_AUDIO_DATABITS_E audio_databits,
                           TUYA_AUDIO_CHANNEL_E audio_channel);

VOID *thread_live_video(VOID *arg);
VOID *thread_live_audio(VOID *arg);

void *thread_live_video2(void *arg);


VOID IPC_APP_Init_Media_Task();


/* get snapshot*/
int IPC_APP_get_snapshot(char *snap_addr, int *snap_size);

/* TUYA_APP_Init_Ring_Buffer */
OPERATE_RET TUYA_APP_Init_Ring_Buffer(CONST IPC_MEDIA_INFO_T *pMediaInfo, INT_T channel);

/* Send the raw data of audio and video  to the SDK */
OPERATE_RET TUYA_APP_Put_Frame(RING_BUFFER_USER_HANDLE_T handle,IN CONST MEDIA_FRAME_T *p_frame);

/* snapshot callback of TUYA SDK*/
VOID TUYA_APP_get_snapshot_cb(IN INT_T device, IN INT_T channel, OUT CHAR_T *snap_addr, OUT INT_T *snap_size);

OPERATE_RET TUYA_APP_DeInit_Ring_Buffer(INT_T channel);

#ifdef __cplusplus
}
#endif

#endif  /* _TUYA_IPC_MEDIA_UTILS_H */
